import { Controller, Get, Query, UseGuards } from '@nestjs/common';
import { DashboardService } from './dashboard.service';
import { AuthGuard } from '@nestjs/passport';
import { Roles } from 'src/auth/decorators/roles.decorator';
import { RolesGuard } from 'src/auth/guards/roles.guard';
import { UserRole } from 'src/enum';
import { CurrentUser } from 'src/auth/decorators/current-user.decorator';
import { Account } from 'src/account/entities/account.entity';
import { DateFilterDto } from 'src/common/dto/date.dto';

@Controller('dashboard')
export class DashboardController {
  constructor(private readonly dashboardService: DashboardService) {}

  @Get('business/count')
  businessCount(@Query() dto: DateFilterDto) {
    return this.dashboardService.businessCount(dto);
  }

  @Get('amcUser')
  amcUsers() {
    return this.dashboardService.amcUsers();
  }

  @Get('count')
  @UseGuards(AuthGuard('jwt'), RolesGuard)
  @Roles(UserRole.BUSINESS)
  getCount(@CurrentUser() user: Account) {
    return this.dashboardService.getCount(user.id);
  }
}
